| Title: | Interactive Document for Working with KNN Analysis |
|---|---|
| Description: | An interactive document on the topic of K-nearest neighbour (KNN) using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at <https://kartikeyabolar.shinyapps.io/KNNShiny/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-16 06:02:16 UTC |
| Source: | https://github.com/cran/KNNShiny |
KNNShiny() loads interactive user interface built using R 'shiny'.
KNNShiny()KNNShiny()
Start KNNShiny
The interactive user interface is to provide an easy way for K-nearest neighbour(KNN) analaysis and downloading relevant plot.
Nothing
if(interactive()){ library(rmarkdown) KNNShiny() }if(interactive()){ library(rmarkdown) KNNShiny() }